==> hologram-python-0.5.28.tar.gz: hologram-python-0.5.28/scripts/hologram_receive.py <==
#!/usr/bin/env python

# hologram_receive.py - Hologram Python SDK command line interface (CLI) for inbound messages.
#
# Author: Hologram <support@hologram.io>
#
# Copyright 2016 - Hologram (Konekt, Inc.)
#
# LICENSE: Distributed under the terms of the MIT License

from Hologram.HologramCloud import HologramCloud
from hologram_util import handle_timeout
from hologram_util import handle_polling

help_data = '''This subcommand allows you to listen on a given host and port for incoming cloud messages.\n
'''

help_sms = '''This subcommand allows you to listen on a given host and port for incoming SMS.\n
'''

hologram = None

def popReceivedMessage():
    recv = hologram.popReceivedMessage()
    if recv is not None:
        print 'Received message: ' + str(recv)

def popReceivedSMS():
    recv = hologram.popReceivedSMS()
    if recv is not None:
        print 'Received SMS:', recv

def parse_hologram_receive_args(parser):
    parser.add_argument('-m', '--modem', nargs='?', default='nova',
                        help='The modem type. Choose between nova, ms2131 and e303.')
    parser.add_argument('-v', '--verbose', action='store_true', required=False)
    parser.add_argument('-t', '--timeout', type=int, nargs='?', default=-1,
                        help='The number of seconds before the socket is closed. Default is to block indefinitely.')
    parse_data_args(parser)
    parse_sms_args(parser)

def parse_data_args(parser):
    parser.set_defaults(command_selected='receive_data')
    parser.add_argument('--data', action='store_true', required=False)

def parse_sms_args(parser):
    parser.set_defaults(command_selected='receive_sms')
    parser.add_argument('--sms', action='store_true', required=False)

def run_hologram_receive(args):

    if args['data'] and args['sms']:
        raise Exception('must pick either one of data or sms')
    if args['sms']:
        run_hologram_receive_sms(args)
    else:
        run_hologram_receive_data(args)

# EFFECTS: Receives data from the Hologram Cloud.
def run_hologram_receive_data(args):

    global hologram
    hologram = HologramCloud(None, network='cellular')

    hologram.event.subscribe('message.received', popReceivedMessage)
    result = hologram.network.connect()
    if result == False:
        print 'Failed to connect to cell network'

    print 'Listening to port ' + str(hologram.receive_port)
    hologram.initializeReceiveSocket()

    handle_timeout(args['timeout'])

    hologram.closeReceiveSocket()

    hologram.network.disconnect()


# EFFECTS: Receives SMS from the Hologram Cloud.
def run_hologram_receive_sms(args):
    global hologram
    hologram = HologramCloud(None, network='cellular')
    handle_polling(args['timeout'], popReceivedSMS, 1)

==> hologram-python-0.6.0.tar.gz: hologram-python-0.6.0/scripts/hologram_receive.py <==
#!/usr/bin/env python

# hologram_receive.py - Hologram Python SDK command line interface (CLI) for inbound messages.
#
# Author: Hologram <support@hologram.io>
#
# Copyright 2016 - Hologram (Konekt, Inc.)
#
# LICENSE: Distributed under the terms of the MIT License

from Hologram.HologramCloud import HologramCloud
from hologram_util import handle_timeout
from hologram_util import handle_polling

help_data = '''This subcommand allows you to listen on a given host and port for incoming cloud messages.\n
'''

help_sms = '''This subcommand allows you to listen on a given host and port for incoming SMS.\n
'''

hologram = None

def popReceivedMessage():
    recv = hologram.popReceivedMessage()
    if recv is not None:
        print 'Received message: ' + str(recv)

def popReceivedSMS():
    recv = hologram.popReceivedSMS()
    if recv is not None:
        print 'Received SMS:', recv

def parse_hologram_receive_args(parser):
    parser.add_argument('-m', '--modem', nargs='?', default='nova',
                        help='The modem type. Choose between nova, ms2131 and e303.')
    parser.add_argument('-v', '--verbose', action='store_true', required=False)
    parser.add_argument('-t', '--timeout', type=int, nargs='?', default=-1,
                        help='The number of seconds before the socket is closed. Default is to block indefinitely.')
    parse_data_args(parser)
    parse_sms_args(parser)

def parse_data_args(parser):
    parser.set_defaults(command_selected='receive_data')
    parser.add_argument('--data', action='store_true', required=False)

def parse_sms_args(parser):
    parser.set_defaults(command_selected='receive_sms')
    parser.add_argument('--sms', action='store_true', required=False)

def run_hologram_receive(args):

    if args['data'] and args['sms']:
        raise Exception('must pick either one of data or sms')
    if args['sms']:
        run_hologram_receive_sms(args)
    else:
        run_hologram_receive_data(args)

# EFFECTS: Receives data from the Hologram Cloud.
def run_hologram_receive_data(args):

    global hologram
    hologram = HologramCloud(None, network='cellular')

    hologram.event.subscribe('message.received', popReceivedMessage)
    result = hologram.network.connect()
    if result == False:
        print 'Failed to connect to cell network'

    print 'Listening to port ' + str(hologram.receive_port)
    hologram.openReceiveSocket()

    handle_timeout(args['timeout'])

    hologram.closeReceiveSocket()

    hologram.network.disconnect()


# EFFECTS: Receives SMS from the Hologram Cloud.
def run_hologram_receive_sms(args):
    global hologram
    hologram = HologramCloud(None, network='cellular')
    handle_polling(args['timeout'], popReceivedSMS, 1)
